@@ -211,10 +211,12 @@ trans_beta <- R6Class(classname = "trans_beta",
 			model <- self$res_ordination$model
 			plot_x <- colnames(self$res_ordination$scores)[1]
 			plot_y <- colnames(self$res_ordination$scores)[2]
-			
 			if(!is.null(plot_group_order)){
 				combined[, plot_color] %<>% factor(., levels = plot_group_order)
 			}
+			if(!is.null(plot_color)){
+				color_values <- expand_colors(color_values, length(unique(combined[, plot_color])))
+			}			
 			
 			p <- ggplot(combined, aes_meco(x = plot_x, y = plot_y, colour = plot_color, shape = plot_shape))
 			if("point" %in% plot_type){
@@ -492,7 +494,7 @@ trans_beta <- R6Class(classname = "trans_beta",
 		#' @description
 		#' Plotting clustering result based on the \code{ggdendro} package.
 		#'
-		#' @param use_colors colors for presentation.
+		#' @param color_values default RColorBrewer::brewer.pal(8, "Dark2"); color palette for the text.
 		#' @param measure default NULL; beta diversity index; If NULL, using the measure when creating object
 		#' @param group default NULL; if provided, use this group to assign color.
 		#' @param replace_name default NULL; if provided, use this as label.
@@ -500,7 +502,7 @@ trans_beta <- R6Class(classname = "trans_beta",
 		#' @examples
 		#' t1$plot_clustering(group = "Group", replace_name = c("Saline", "Type"))
 		plot_clustering = function(
-			use_colors = RColorBrewer::brewer.pal(8, "Dark2"), 
+			color_values = RColorBrewer::brewer.pal(8, "Dark2"), 
 			measure = NULL, 
 			group = NULL, 
 			replace_name = NULL
@@ -550,7 +552,7 @@ trans_beta <- R6Class(classname = "trans_beta",
 						g1 <- g1 + geom_text(data=data2, aes_meco(x="x", y="y", label=replace_name, hjust=-0.1, colour = group), size=4)
 					}
 				}
-				g1 <- g1 + scale_color_manual(values = use_colors)
+				g1 <- g1 + scale_color_manual(values = color_values)
 			}
 			g1 <- g1 + theme(legend.position="none") + coord_flip() +
 				scale_x_discrete(labels=ggdendro::label(hc_d_measure)$label) +
